@@ -8,8 +8,8 @@ public class OverwriteMotion {
         Action3D a3 = new Action3D("x-res:///axis.a3");
         BVH bvh = new BVH(new URL("x-rzip:x-res:///axis.a3!/spin.bvh"));
         a3.setMotion("halt",bvh);
+        a3.changeImmediately("halt");
         w.add(a3);
-        a3.change("halt");
     }
 }
 
