@@ -326,6 +326,74 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
         return universe.getCameraScale();
     }
 
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt) {
+        universe.setCameraLookAtPoint(lookAt);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt) {
+        universe.setCameraLookAtPointImmediately(lookAt);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z) {
+        universe.setCameraLookAtPoint(x,y,z);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z) {
+        universe.setCameraLookAtPointImmediately(x,y,z);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up) {
+        universe.setCameraLookAtPoint(lookAt,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up) {
+        universe.setCameraLookAtPointImmediately(lookAt,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up) {
+        universe.setCameraLookAtPoint(x,y,z,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up) {
+        universe.setCameraLookAtPointImmediately(x,y,z,up);
+    }
+
     /**
      * ヘッドライトのON,OFFを設定します。
      */
@@ -361,6 +429,8 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
     /**
      * A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c) {
         universe.setA3Controller(c);
@@ -510,6 +580,9 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
                 continue;
             c.paint(gg,this);
         }
+        if (Component2D.advertisement!=null) {
+            Component2D.advertisement.paint(gg,this);
+        }
         gg.flush(true);
     }
 //  ----------おまけ機能---------
@@ -765,6 +838,75 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
     public double getCameraScale(int scene) {
         return universe.getCameraScale(scene);
     }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,int scene) {
+        universe.setCameraLookAtPoint(lookAt,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,int scene) {
+        universe.setCameraLookAtPointImmediately(lookAt,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,int scene) {
+        universe.setCameraLookAtPoint(x,y,z,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,int scene) {
+        universe.setCameraLookAtPointImmediately(x,y,z,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up,int scene) {
+        universe.setCameraLookAtPoint(lookAt,up,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up,int scene) {
+        universe.setCameraLookAtPointImmediately(lookAt,up,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up,int scene) {
+        universe.setCameraLookAtPoint(x,y,z,up,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up,int scene) {
+        universe.setCameraLookAtPointImmediately(x,y,z,up,scene);
+    }
+
     /**
      * シーンを指定して、ナビゲーションモードを指定します。
      */
@@ -791,6 +933,8 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
     /**
      * シーンを指定して、A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c,int scene) {
         universe.setA3Controller(c,scene);
