@@ -3,6 +3,7 @@ package jp.sourceforge.acerola3d.a3;
 import java.awt.*;
 import java.awt.event.KeyListener;
 import javax.vecmath.*;
+
 import java.io.*;
 
 /**
@@ -206,6 +207,58 @@ public interface A3CanvasInterface {
      */
     public double getCameraScale();
 
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt);
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt);
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z);
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z);
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up);
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up);
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up);
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up);
+
     /**
      * ヘッドライトのON,OFFを設定します。
      */
@@ -263,6 +316,8 @@ public interface A3CanvasInterface {
     /**
      * A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c);
 //  ----------座標変換とピッキングのためのラッパーメソッド---------
@@ -524,6 +579,59 @@ public interface A3CanvasInterface {
      * シーンを指定して、カメラの拡大率を返します。
      */
     public double getCameraScale(int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up,int scene);
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up,int scene);
+
     /**
      * シーンを指定して、ナビゲーションモードを指定します。
      */
@@ -544,6 +652,8 @@ public interface A3CanvasInterface {
     /**
      * シーンを指定して、A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c,int scene);
 
