@@ -14,7 +14,6 @@ public abstract class A3Object {
     static BoundingSphere bs = new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE);
 //    protected static final Serializable NULL = A23.NULL;
 
-
     A3Behavior behavior = null;
     Scene scene = null;
     A3Label label = null;
@@ -350,6 +349,48 @@ public abstract class A3Object {
         return null;
     }
 
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * 指定した座標に向くように回転をセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPoint(Vector3d lookAt) {
+        behavior.setLookAtPoint(lookAt);
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * 指定した座標に向くように回転を即時にセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPointImmediately(Vector3d lookAt) {
+        behavior.setLookAtPointImmediately(lookAt);
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * 指定した座標に向くように回転をセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPoint(double x,double y,double z) {
+        Vector3d lookAt = new Vector3d(x,y,z);
+        behavior.setLookAtPoint(lookAt);
+    }
+
+    /**
+     * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
+     * 指定した座標に向くように回転を即時にセットします。その時の計算に
+     * 使用する上方向ベクトルはgetUpperVector()で得られる物を
+     * 使用します。
+     */
+    public final void setLookAtPointImmediately(double x,double y,double z) {
+        Vector3d lookAt = new Vector3d(x,y,z);
+        behavior.setLookAtPointImmediately(lookAt);
+    }
+
     /**
      * 拡大率をセットするためのメソッド。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -533,4 +574,26 @@ public abstract class A3Object {
     public boolean getPickable() {
         return pickable;
     }
+
+    /**
+     * 3D表示版の選択印に使用される3Dオブジェクトをセットします。
+     * ここで指定された3DオブジェクトがconeTree()メソッドで複製され
+     * 選択印として使用されます。
+     */
+    public static void setSelected3DMarker(Node n) {
+        A3Behavior.setSelected3DMarker(n);
+    }
+    /**
+     * 3D表示版の選択印の表示・非表示を設定します。
+     */
+    public void setSelected3D(boolean b) {
+        behavior.setSelected3D(b);
+    }
+    /**
+     * 3D表示版の選択印のが表示される状態ならtrueを
+     * 非表示ならfalseを返します。
+     */
+    public boolean isSelected3D() {
+        return behavior.isSelected3D();
+    }
 }
