@@ -1,12 +1,15 @@
 package jp.sourceforge.acerola3d.a3;
 
 import java.awt.*;
+import java.awt.event.KeyListener;
 
 import javax.media.j3d.*;
 import javax.vecmath.*;
 
 import java.util.*;
 
+import java.io.File;
+import java.io.IOException;
 import java.lang.reflect.Constructor;
 import jp.sourceforge.acerola3d.a3.A3CanvasInterface.NaviMode;
 import java.security.AccessController;
@@ -16,7 +19,7 @@ import java.security.PrivilegedAction;
  * A3CanvasとJA3Canvasの両方で共通して使うことが
  * できるVirtualUniverseのAcerola3Dバージョン。
  */
-class A3VirtualUniverse extends VirtualUniverse {
+class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
     A3CanvasInterface canvas = null;
     Canvas3D canvas3d = null;
     javax.media.j3d.Locale locale;
@@ -421,6 +424,66 @@ class A3VirtualUniverse extends VirtualUniverse {
         return scene.getCameraScale();
     }
 
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt) {
+        scene.setCameraLookAtPoint(lookAt);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt) {
+        scene.setCameraLookAtPointImmediately(lookAt);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z) {
+        scene.setCameraLookAtPoint(x,y,z);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z) {
+        scene.setCameraLookAtPointImmediately(x,y,z);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up) {
+        scene.setCameraLookAtPoint(lookAt,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up) {
+        scene.setCameraLookAtPoint(x,y,z,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up) {
+        scene.setCameraLookAtPointImmediately(x,y,z,up);
+    }
+
     /**
      * ヘッドライトのON,OFFを設定します。
      */
@@ -454,6 +517,8 @@ class A3VirtualUniverse extends VirtualUniverse {
     /**
      * A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c) {
         scene.setA3Controller(c);
@@ -891,6 +956,107 @@ class A3VirtualUniverse extends VirtualUniverse {
         else
             throw new IllegalArgumentException();
     }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPoint(lookAt);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPointImmediately(lookAt);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPoint(x,y,z);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPointImmediately(x,y,z);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPoint(lookAt,up);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPointImmediately(lookAt,up);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPoint(x,y,z,up);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPointImmediately(x,y,z,up);
+        else
+            throw new IllegalArgumentException();
+    }
+
     /**
      * シーンを指定して、ナビゲーションモードを指定します。
      */
@@ -929,6 +1095,8 @@ class A3VirtualUniverse extends VirtualUniverse {
     /**
      * シーンを指定して、A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c,int scene) {
         Scene s = scenes.get(scene);
@@ -1010,28 +1178,28 @@ class A3VirtualUniverse extends VirtualUniverse {
      * A3Objectを追加してカメラに対して固定した位置に
      * 表示されるようにします。
      */
-    void addLockedA3(A3Object a) {
+    public void addLockedA3(A3Object a) {
         scene.addLockedA3(a);
     }
     /**
      * 指定されたA3Objectの登録を削除してカメラに対して固定した
      * 位置に表示されないようにします。
      */
-    void delLockedA3(A3Object a) {
+    public void delLockedA3(A3Object a) {
         scene.delLockedA3(a);
     }
     /**
      * カメラに対して固定して表示されるようい登録されている
      * 全てのA3Objectを削除して表示されないようにします。
      */
-    void delAllLockedA3() {
+    public void delAllLockedA3() {
         scene.delAllLockedA3();
     }
     /**
      * シーンを指定して、A3Objectを追加してカメラに対して固定した位置に
      * 表示されるようにします。
      */
-    void addLockedA3(A3Object a,int scene) {
+    public void addLockedA3(A3Object a,int scene) {
         Scene s = scenes.get(scene);
         if (s!=null)
             s.addLockedA3(a);
@@ -1042,7 +1210,7 @@ class A3VirtualUniverse extends VirtualUniverse {
      * シーンを指定して、指定されたA3Objectの登録を削除してカメラに対して固定した
      * 位置に表示されないようにします。
      */
-    void delLockedA3(A3Object a,int scene) {
+    public void delLockedA3(A3Object a,int scene) {
         Scene s = scenes.get(scene);
         if (s!=null)
             s.delLockedA3(a);
@@ -1053,7 +1221,7 @@ class A3VirtualUniverse extends VirtualUniverse {
      * シーンを指定して、カメラに対して固定して表示されるようい登録されている
      * 全てのA3Objectを削除して表示されないようにします。
      */
-    void delAllLockedA3(int scene) {
+    public void delAllLockedA3(int scene) {
         Scene s = scenes.get(scene);
         if (s!=null)
             s.delAllLockedA3();
@@ -1100,4 +1268,19 @@ class A3VirtualUniverse extends VirtualUniverse {
         else
             throw new IllegalArgumentException();
     }
+    public void addKeyListener(KeyListener l) {
+        //dummy
+    }
+    @Override
+    public void removeKeyListener(KeyListener l) {
+        //dummy
+    }
+    @Override
+    public void saveImage(File file) throws IOException {
+        //dummy
+    }
+    @Override
+    public void setCameraLookAtPointImmediately(Vector3d lookAt, Vector3d up) {
+        //dummy
+    }
 }
