@@ -26,6 +26,7 @@ import javax.xml.xpath.*;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 
+import jp.sourceforge.acerola3d.A23;
 import jp.sourceforge.acerola3d.a3.bvh.*;
 
 import jp.sourceforge.acerola3d.a3.catalog.*;
@@ -100,7 +101,6 @@ class Action3DData {
         boolean loopFlag;
         String bvhFile;
         String soundFile;
-        boolean soundLoop;
         String soundType = "PointSound";
         float soundGain = 1.0f;
         float soundOffsetXYZ[] = {0.0f,0.0f,0.0f};
@@ -132,7 +132,6 @@ class Action3DData {
             ret.loopFlag = loopFlag;
             ret.bvhFile = bvhFile;
             ret.soundFile = soundFile;
-            ret.soundLoop = soundLoop;
             ret.soundType = soundType;
             ret.soundGain = soundGain;
             ret.soundOffsetXYZ = soundOffsetXYZ.clone();
@@ -300,10 +299,7 @@ class Action3DData {
                 }
                 sound.setEnable(false);
                 sound.setPause(false);
-                if (soundLoop)
-                    sound.setLoop(-1);
-                else
-                    sound.setLoop(0);
+                sound.setLoop(0);
                 //sound.setContinuousEnable(true);
                 sound.setSchedulingBounds(bounding);
                 sound.setCapability(Sound.ALLOW_ENABLE_WRITE);
@@ -482,6 +478,7 @@ class Action3DData {
         loadAllShapes();
         loadAllMotions();
         loadAllSounds();
+        A23.clearZipCache();
     }
 
     //cloneのような浅いコピーじゃなくて，かといって深い
@@ -634,7 +631,6 @@ class Action3DData {
             S s = aNode.getS();
             if (s!=null) {
                 a.soundFile = s.getFile();
-                a.soundLoop = s.isLoop();
                 if (s.getType()==SoundType.POINT_SOUND)
                     a.soundType = "PointSound";
                 else if (s.getType()==SoundType.BACKGROUND_SOUND)
@@ -858,9 +854,6 @@ class Action3DData {
                 nnm = s_nodes[0].getAttributes();
                 attr = (Attr)nnm.getNamedItem("file");
                 a.soundFile = attr.getValue().trim();
-                attr = (Attr)nnm.getNamedItem("loop");
-                if (attr!=null)
-                    a.soundLoop = Boolean.parseBoolean(attr.getValue().trim());
                 attr = (Attr)nnm.getNamedItem("type");
                 if (attr!=null)
                     a.soundType = attr.getValue().trim();
