@@ -113,6 +113,9 @@ class ActionBehavior extends Behavior implements Cloneable {
         a3Data.allActionBranchGroup.addChild(n);
         a3Data.actions[actionNo].start();
         resetParameters();
+        if (a3.isSelected3D()) {
+            a3.behavior.adjustSelected3D();
+        }
     }
     void init() {
         synchronized (actionQueue) {
@@ -220,6 +223,10 @@ class ActionBehavior extends Behavior implements Cloneable {
                 Transform3D t = a.motion.getTransform3D(boneName,timeD);
                 tg.setTransform(t);
             }
+            //3Dセレクトマーカーのアジャストメント
+            if (a3.isSelected3D()) {
+                a3.behavior.adjustSelected3D();
+            }
 
             //再生後初めてのサウンド再生
             //((newPlayStatus==4)&&(playStatus==0))==trueのような場合も再生する
@@ -320,10 +327,10 @@ class ActionBehavior extends Behavior implements Cloneable {
     }
 
     int getActionNo() {
-        return 0;
+        return actionNo;
     }
     String getActionName() {
-        return null;
+        return a3Data.actions[actionNo].actionName;
     }
     String getActionNameFromActionNo(int an) {
         return a3Data.actions[an].actionName;
