@@ -18,12 +18,12 @@ class CameraBehavior extends Behavior {
         //WakeupOnElapsedTime w = new WakeupOnElapsedTime(100);
         WakeupOnBehaviorPost w = new WakeupOnBehaviorPost(null,1);
         wakeupOn(w);
-        virtualUniverse.cameraNowS = virtualUniverse.cameraNowS + 0.2*(virtualUniverse.cameraNextS - virtualUniverse.cameraNowS);
-        virtualUniverse.cameraNowQ.normalize();
-        virtualUniverse.cameraNowQ.interpolate(virtualUniverse.cameraNextQ,0.2);
-        virtualUniverse.cameraNowQ.normalize();
-        virtualUniverse.cameraNowV.interpolate(virtualUniverse.cameraNextV,0.2);
-        virtualUniverse.transform.set(virtualUniverse.cameraNowQ,virtualUniverse.cameraNowV,virtualUniverse.cameraNowS);
+        virtualUniverse.scene.cameraNowS = virtualUniverse.scene.cameraNowS + 0.2*(virtualUniverse.scene.cameraNextS - virtualUniverse.scene.cameraNowS);
+        virtualUniverse.scene.cameraNowQ.normalize();
+        virtualUniverse.scene.cameraNowQ.interpolate(virtualUniverse.scene.cameraNextQ,0.2);
+        virtualUniverse.scene.cameraNowQ.normalize();
+        virtualUniverse.scene.cameraNowV.interpolate(virtualUniverse.scene.cameraNextV,0.2);
+        virtualUniverse.transform.set(virtualUniverse.scene.cameraNowQ,virtualUniverse.scene.cameraNowV,virtualUniverse.scene.cameraNowS);
         virtualUniverse.tGroup.setTransform(virtualUniverse.transform);
     }
 }
