@@ -307,6 +307,75 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
         return canvas.getCameraScale();
     }
 
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt) {
+        canvas.setCameraLookAtPoint(lookAt);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt) {
+        canvas.setCameraLookAtPointImmediately(lookAt);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z) {
+        canvas.setCameraLookAtPoint(x,y,z);
+    }
+
+    /**
+     * ルックアットポイントを使って、カメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z) {
+        canvas.setCameraLookAtPointImmediately(x,y,z);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up) {
+        canvas.setCameraLookAtPoint(lookAt,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up) {
+        canvas.setCameraLookAtPointImmediately(lookAt,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up) {
+        canvas.setCameraLookAtPoint(x,y,z,up);
+    }
+
+    /**
+     * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up) {
+        canvas.setCameraLookAtPointImmediately(x,y,z,up);
+    }
+
+
     /**
      * ヘッドライトのON,OFFを設定します。
      */
@@ -342,6 +411,8 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
     /**
      * A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c) {
         canvas.setA3Controller(c);
@@ -672,6 +743,75 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
     public double getCameraScale(int scene) {
         return canvas.getCameraScale(scene);
     }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,int scene) {
+        canvas.setCameraLookAtPoint(lookAt,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,int scene) {
+        canvas.setCameraLookAtPointImmediately(lookAt,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,int scene) {
+        canvas.setCameraLookAtPoint(x,y,z,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントを使ってカメラの回転を即時に指定します。
+     * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
+     * 値を用いて計算します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,int scene) {
+        canvas.setCameraLookAtPointImmediately(x,y,z,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up,int scene) {
+        canvas.setCameraLookAtPoint(lookAt,up,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(Vector3d lookAt,Vector3d up,int scene) {
+        canvas.setCameraLookAtPointImmediately(lookAt,up,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(double x,double y,double z,Vector3d up,int scene) {
+        canvas.setCameraLookAtPoint(x,y,z,up,scene);
+    }
+
+    /**
+     * シーンを指定し、ルックアットポイントと上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up,int scene) {
+        canvas.setCameraLookAtPointImmediately(x,y,z,up,scene);
+    }
+
     /**
      * シーンを指定して、ナビゲーションモードを指定します。
      */
@@ -698,6 +838,8 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
     /**
      * シーンを指定して、A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
+     * また，設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい．
      */
     public void setA3Controller(A3Controller c,int scene) {
         canvas.setA3Controller(c,scene);
