@@ -487,6 +487,9 @@ class TransCanvas3D extends JPanel implements AncestorListener {
                             continue;
                         c.paint(g2,widget);
                     }
+                    if (Component2D.advertisement!=null) {
+                        Component2D.advertisement.paint(g2,widget);
+                    }
                     //g2.flush(true);
                     g2.dispose();
                 }
